@@ -23,10 +23,15 @@
 
 #include <QColor>
 #include <QDate>
+#include <QFont>
 #include <QList>
 #include <QMap>
 #include <QString>
 
+#include <KGlobalSettings>
+#include <KStandardDirs>
+#include <KUrl>
+
 /**
  * This file contains data structures used to store information about
  * an interface. It is shared between the daemon and the control center
@@ -95,6 +100,7 @@ static const char conf_colorOutgoingMax[] = "ColorOutgoingMax";
 static const char conf_barScale[] = "BarScale";
 static const char conf_inMaxRate[] = "InMaxRate";
 static const char conf_outMaxRate[] = "OutMaxRate";
+static const char conf_iconFont[] = "IconFont";
 
 // interface statistics
 static const char conf_activateStatistics[] = "ActivateStatistics";
@@ -103,6 +109,8 @@ static const char conf_calendar[] = "Calendar";
 static const char conf_billingStart[] = "BillingStart";
 static const char conf_billingMonths[] = "BillingMonths";
 static const char conf_billingWarnThresh[] = "BillingWarnThreshold";
+static const char conf_billingWarnUnits[] = "BillingWarnUnits";
+static const char conf_billingWarnType[] = "BillingWarnType";
 static const char conf_billingWarnRxTx[] = "BillingWarnRxTx";
 
 // interface context menu
@@ -118,13 +126,52 @@ static const char conf_toolTipContent[] = "ToolTipContent";
 static const char conf_pollInterval[] = "PollInterval";
 static const char conf_saveInterval[] = "SaveInterval";
 static const char conf_statisticsDir[] = "StatisticsDir";
+static const char conf_useBitrate[] = "UseBitrate";
 static const char conf_plotterPos[] = "PlotterPos";
 static const char conf_plotterSize[] = "PlotterSize";
 static const char conf_statisticsPos[] = "StatisticsPos";
 static const char conf_statisticsSize[] = "StatisticsSize";
 static const char conf_statusPos[] = "StatusPos";
 static const char conf_statusSize[] = "StatusSize";
+static const char conf_hourState[] = "HourState";
+static const char conf_dayState[] = "DayState";
+static const char conf_weekState[] = "WeekState";
+static const char conf_monthState[] = "MonthState";
+static const char conf_yearState[] = "YearState";
 
+enum ToolTipEnums
+{
+    INTERFACE        = 0x00000001,
+    ALIAS            = 0x00000002,
+    STATUS           = 0x00000004,
+    UPTIME           = 0x00000008,
+    IP_ADDRESS       = 0x00000010,
+    SCOPE            = 0x00000020,
+    HW_ADDRESS       = 0x00000040,
+    PTP_ADDRESS      = 0x00000080,
+    RX_PACKETS       = 0x00000100,
+    TX_PACKETS       = 0x00000200,
+    RX_BYTES         = 0x00000400,
+    TX_BYTES         = 0x00000800,
+    ESSID            = 0x00001000,
+    MODE             = 0x00002000,
+    FREQUENCY        = 0x00004000,
+    BIT_RATE         = 0x00008000,
+    ACCESS_POINT     = 0x00010000,
+    LINK_QUALITY     = 0x00020000,
+    BCAST_ADDRESS    = 0x00040000,
+    GATEWAY          = 0x00080000,
+    DOWNLOAD_SPEED   = 0x00100000,
+    UPLOAD_SPEED     = 0x00200000,
+    NICK_NAME        = 0x00400000,
+    ENCRYPTION       = 0x00800000
+};
+
+#ifdef HAVE_KSTATUSNOTIFIERITEM
+static const int defaultTip = STATUS | IP_ADDRESS | RX_BYTES | TX_BYTES | ESSID | LINK_QUALITY | DOWNLOAD_SPEED | UPLOAD_SPEED | ENCRYPTION;
+#else
+static const int defaultTip = INTERFACE | STATUS | IP_ADDRESS | RX_BYTES | TX_BYTES | ESSID | LINK_QUALITY | DOWNLOAD_SPEED | UPLOAD_SPEED | ENCRYPTION;
+#endif
 
 struct KNemoTheme
 {
@@ -203,6 +250,22 @@ struct InterfaceCommand
     QString menuText;
 };
 
+struct GeneralSettings
+{
+    GeneralSettings()
+      : toolTipContent( defaultTip ),
+        pollInterval( 1.0 ),
+        saveInterval( 60 ),
+        useBitrate( false ),
+        statisticsDir( KGlobal::dirs()->saveLocation( "data", "knemo/" ) )
+    {}
+    int toolTipContent;
+    double pollInterval;
+    int saveInterval;
+    bool useBitrate;
+    KUrl statisticsDir;
+};
+
 struct InterfaceSettings
 {
     InterfaceSettings()
@@ -217,9 +280,12 @@ struct InterfaceSettings
         barScale( false ),
         inMaxRate( 4 ),
         outMaxRate( 4 ),
+        iconFont( KGlobalSettings::generalFont() ),
         numCommands( 0 ),
         trafficThreshold( 0 ),
         warnThreshold( 0.0 ),
+        warnUnits( 3 ),
+        warnType( 2 ),
         warnTotalTraffic( false ),
         hideWhenUnavailable( false ),
         hideWhenDisconnected( false ),
@@ -239,9 +305,12 @@ struct InterfaceSettings
     bool barScale;
     unsigned int inMaxRate;
     unsigned int outMaxRate;
+    QFont iconFont;
     int numCommands;
     unsigned int trafficThreshold;
     double warnThreshold;
+    int warnUnits;
+    int warnType;
     bool warnTotalTraffic;
     bool hideWhenUnavailable;
     bool hideWhenDisconnected;
@@ -265,36 +334,16 @@ enum rt_scope_t
 };
 #endif
 
-enum ToolTipEnums
+enum NotificationType
 {
-    INTERFACE        = 0x00000001,
-    ALIAS            = 0x00000002,
-    STATUS           = 0x00000004,
-    UPTIME           = 0x00000008,
-    IP_ADDRESS       = 0x00000010,
-    SCOPE            = 0x00000020,
-    HW_ADDRESS       = 0x00000040,
-    PTP_ADDRESS      = 0x00000080,
-    RX_PACKETS       = 0x00000100,
-    TX_PACKETS       = 0x00000200,
-    RX_BYTES         = 0x00000400,
-    TX_BYTES         = 0x00000800,
-    ESSID            = 0x00001000,
-    MODE             = 0x00002000,
-    FREQUENCY        = 0x00004000,
-    BIT_RATE         = 0x00008000,
-    ACCESS_POINT     = 0x00010000,
-    LINK_QUALITY     = 0x00020000,
-    BCAST_ADDRESS    = 0x00040000,
-    GATEWAY          = 0x00080000,
-    DOWNLOAD_SPEED   = 0x00100000,
-    UPLOAD_SPEED     = 0x00200000,
-    NICK_NAME        = 0x00400000,
-    ENCRYPTION       = 0x00800000
+    NotifyHour,
+    NotifyDay,
+    NotifyMonth,
+    NotifyRoll24Hour,
+    NotifyRoll7Day,
+    NotifyRoll30Day
 };
 
-static const int defaultTip = INTERFACE | STATUS | IP_ADDRESS | ESSID | LINK_QUALITY | DOWNLOAD_SPEED | UPLOAD_SPEED;
-
 static const double pollIntervals[] = { 0.1, 0.2, 0.25, 0.5, 1.0, 2.0 };
 
 #endif // DATA_H
