@@ -65,14 +65,13 @@ static bool themesLessThan( const KNemoTheme& s1, const KNemoTheme& s2 )
 ConfigDialog::ConfigDialog( QWidget *parent, const QVariantList &args )
     : KCModule( KNemoFactory::componentData(), parent, args ),
       mLock( false ),
-      mDlg( new Ui::ConfigDlg() ),
-
-      // If we're going to change KGlobal::locale()->calendar() we're
-      // going to need to track the original calendar type.
-      // TODO: Some of the calendars are a bit buggy, so default to Gregorian for now
-      //mDefaultCalendarType( KGlobal::locale()->calendarType() ),
-      mDefaultCalendarType( "gregorian" )
+      mDlg( new Ui::ConfigDlg() )
 {
+    if ( KDE::versionMajor() >= 4 && KDE::versionMinor() >= 4 )
+        mDefaultCalendarType = KGlobal::locale()->calendarType();
+    else
+        mDefaultCalendarType = "gregorian";
+
     mConfig = KSharedConfig::openConfig( "knemorc" );
 
     setupToolTipMap();
@@ -109,6 +108,16 @@ ConfigDialog::ConfigDialog( QWidget *parent, const QVariantList &args )
     mDlg->comboBoxIconTheme->addItem( netloadTheme.name, QVariant::fromValue( netloadTheme ) );
     mDlg->comboBoxIconTheme->addItem( textTheme.name, QVariant::fromValue( textTheme ) );
 
+    mDlg->warnType->addItem( i18n( "Hour" ), NotifyHour );
+    mDlg->warnType->addItem( i18n( "Day" ), NotifyDay );
+    mDlg->warnType->addItem( i18n( "Month" ), NotifyMonth );
+    mDlg->warnType->addItem( i18n( "Rolling 24 hours" ), NotifyRoll24Hour );
+    mDlg->warnType->addItem( i18n( "Rolling 7 days" ), NotifyRoll7Day );
+    mDlg->warnType->addItem( i18n( "Rolling 30 days" ), NotifyRoll30Day );
+
+    mDlg->warnUnits->addItem( i18n( "MiB" ), 2 );
+    mDlg->warnUnits->addItem( i18n( "GiB" ), 3 );
+
     InterfaceSettings s;
     int index = findIndexFromName( s.iconTheme );
     if ( index < 0 )
@@ -162,6 +171,8 @@ ConfigDialog::ConfigDialog( QWidget *parent, const QVariantList &args )
              this, SLOT( colorButtonChanged() ) );
     connect( mDlg->colorUnavailable, SIGNAL( changed( const QColor& ) ),
              this, SLOT( colorButtonChanged() ) );
+    connect( mDlg->iconFont, SIGNAL( currentFontChanged( const QFont& ) ),
+             this, SLOT( iconFontChanged( const QFont& ) ) );
     connect( mDlg->advancedButton, SIGNAL( clicked() ),
              this, SLOT( advancedButtonClicked() ) );
 
@@ -176,6 +187,10 @@ ConfigDialog::ConfigDialog( QWidget *parent, const QVariantList &args )
              this, SLOT( billingMonthsInputChanged( int ) ) );
     connect( mDlg->warnThreshold, SIGNAL( valueChanged( double ) ),
              this, SLOT( warnThresholdChanged ( double ) ) );
+    connect( mDlg->warnUnits, SIGNAL( activated( int ) ),
+             this, SLOT( warnUnitsChanged( int ) ) );
+    connect( mDlg->warnType, SIGNAL( activated( int ) ),
+             this, SLOT( warnTypeChanged( int ) ) );
     connect( mDlg->warnRxTx, SIGNAL( toggled( bool ) ),
              this, SLOT( warnRxTxToggled ( bool ) ) );
 
@@ -206,6 +221,8 @@ ConfigDialog::ConfigDialog( QWidget *parent, const QVariantList &args )
              this, SLOT( changed() ) );
     connect( mDlg->numInputSaveInterval, SIGNAL( valueChanged( int ) ),
              this, SLOT( changed() ) );
+    connect( mDlg->useBitrate, SIGNAL( toggled( bool ) ),
+             this, SLOT( changed() ) );
 }
 
 ConfigDialog::~ConfigDialog()
@@ -239,14 +256,16 @@ void ConfigDialog::load()
     KConfigGroup generalGroup( config, confg_general );
     bool startKNemo = generalGroup.readEntry( conf_autoStart, true );
     mDlg->checkBoxStartKNemo->setChecked( startKNemo );
-    double pollVal = clamp<double>(generalGroup.readEntry( conf_pollInterval, 1.0 ), 0.1, 2.0 );
+    GeneralSettings g;
+    double pollVal = clamp<double>(generalGroup.readEntry( conf_pollInterval, g.pollInterval ), 0.1, 2.0 );
     pollVal = validatePoll( pollVal );
     int index = mDlg->comboBoxPoll->findData( pollVal );
     if ( index >= 0 )
         mDlg->comboBoxPoll->setCurrentIndex( index );
-    mDlg->numInputSaveInterval->setValue( clamp<int>(generalGroup.readEntry( conf_saveInterval, 60 ), 0, 300 ) );
-    mDlg->lineEditStatisticsDir->setUrl( generalGroup.readEntry( conf_statisticsDir, KGlobal::dirs()->saveLocation( "data", "knemo/" ) ) );
-    mToolTipContent = generalGroup.readEntry( conf_toolTipContent, defaultTip );
+    mDlg->numInputSaveInterval->setValue( clamp<int>(generalGroup.readEntry( conf_saveInterval, g.saveInterval ), 0, 300 ) );
+    mDlg->useBitrate->setChecked( generalGroup.readEntry( conf_useBitrate, g.useBitrate ) );
+    mDlg->lineEditStatisticsDir->setUrl( generalGroup.readEntry( conf_statisticsDir, g.statisticsDir ) );
+    mToolTipContent = generalGroup.readEntry( conf_toolTipContent, g.toolTipContent );
 
     QStringList list = generalGroup.readEntry( conf_interfaces, QStringList() );
 
@@ -270,6 +289,7 @@ void ConfigDialog::load()
             KColorScheme scheme(QPalette::Active, KColorScheme::View);
             settings->colorDisabled = interfaceGroup.readEntry( conf_colorDisabled, scheme.foreground( KColorScheme::InactiveText ).color() );
             settings->colorUnavailable = interfaceGroup.readEntry( conf_colorUnavailable, scheme.foreground( KColorScheme::InactiveText ).color() );
+            settings->iconFont = interfaceGroup.readEntry( conf_iconFont, s.iconFont );
             settings->dynamicColor = interfaceGroup.readEntry( conf_dynamicColor, s.dynamicColor );
             settings->colorIncomingMax = interfaceGroup.readEntry( conf_colorIncomingMax, s.colorIncomingMax );
             settings->colorOutgoingMax = interfaceGroup.readEntry( conf_colorOutgoingMax, s.colorOutgoingMax );
@@ -281,6 +301,8 @@ void ConfigDialog::load()
             settings->calendar = interfaceGroup.readEntry( conf_calendar, mDefaultCalendarType );
             settings->billingMonths = clamp<int>(interfaceGroup.readEntry( conf_billingMonths, s.billingMonths ), 1, 6 );
             settings->warnThreshold = clamp<double>(interfaceGroup.readEntry( conf_billingWarnThresh, s.warnThreshold ), 0.0, 9999.0 );
+            settings->warnUnits = clamp<int>(interfaceGroup.readEntry( conf_billingWarnUnits, s.warnUnits ), 2, 3 );
+            settings->warnType = clamp<int>(interfaceGroup.readEntry( conf_billingWarnType, s.warnType ), 0, 5 );
             settings->warnTotalTraffic = interfaceGroup.readEntry( conf_billingWarnRxTx, s.warnTotalTraffic );
 
              // If no start date saved, default to first of month.
@@ -391,6 +413,11 @@ void ConfigDialog::save()
         QSize statisticsSize = interfaceGroup.readEntry( conf_statisticsSize, QSize() );
         QPoint statusPos = interfaceGroup.readEntry( conf_statusPos, QPoint() );
         QSize statusSize = interfaceGroup.readEntry( conf_statusSize, QSize() );
+        QByteArray hourState = interfaceGroup.readEntry( conf_hourState, QByteArray() );
+        QByteArray dayState = interfaceGroup.readEntry( conf_dayState, QByteArray() );
+        QByteArray weekState = interfaceGroup.readEntry( conf_weekState, QByteArray() );
+        QByteArray monthState = interfaceGroup.readEntry( conf_monthState, QByteArray() );
+        QByteArray yearState = interfaceGroup.readEntry( conf_yearState, QByteArray() );
 
         // Make sure we don't get crufty commands left over
         interfaceGroup.deleteGroup();
@@ -409,6 +436,16 @@ void ConfigDialog::save()
             interfaceGroup.writeEntry( conf_statusSize, statusSize );
         if ( !settings->alias.trimmed().isEmpty() )
             interfaceGroup.writeEntry( conf_alias, settings->alias );
+        if ( !hourState.isNull() )
+            interfaceGroup.writeEntry( conf_hourState, hourState );
+        if ( !dayState.isNull() )
+            interfaceGroup.writeEntry( conf_dayState, dayState );
+        if ( !weekState.isNull() )
+            interfaceGroup.writeEntry( conf_weekState, weekState );
+        if ( !monthState.isNull() )
+            interfaceGroup.writeEntry( conf_monthState, monthState );
+        if ( !yearState.isNull() )
+            interfaceGroup.writeEntry( conf_yearState, yearState );
 
         interfaceGroup.writeEntry( conf_hideWhenNotAvail, settings->hideWhenDisconnected );
         interfaceGroup.writeEntry( conf_hideWhenNotExist, settings->hideWhenUnavailable );
@@ -432,6 +469,10 @@ void ConfigDialog::save()
             {
                 interfaceGroup.writeEntry( conf_barScale, settings->barScale );
             }
+            if ( settings->iconTheme == TEXT_THEME && settings->iconFont != KGlobalSettings::generalFont() )
+            {
+                interfaceGroup.writeEntry( conf_iconFont, settings->iconFont );
+            }
             if ( settings->dynamicColor ||
                  ( settings->iconTheme == NETLOAD_THEME && settings->barScale )
                )
@@ -449,7 +490,12 @@ void ConfigDialog::save()
             interfaceGroup.writeEntry( conf_calendar, settings->calendar );
         }
         interfaceGroup.writeEntry( conf_billingWarnThresh, settings->warnThreshold );
-        interfaceGroup.writeEntry( conf_billingWarnRxTx, settings->warnTotalTraffic );
+        if ( settings->warnThreshold > 0 )
+        {
+            interfaceGroup.writeEntry( conf_billingWarnUnits, settings->warnUnits );
+            interfaceGroup.writeEntry( conf_billingWarnType, settings->warnType );
+            interfaceGroup.writeEntry( conf_billingWarnRxTx, settings->warnTotalTraffic );
+        }
 
         interfaceGroup.writeEntry( conf_numCommands, settings->commands.size() );
         for ( int i = 0; i < settings->commands.size(); i++ )
@@ -469,6 +515,7 @@ void ConfigDialog::save()
     generalGroup.writeEntry( conf_autoStart, mDlg->checkBoxStartKNemo->isChecked() );
     generalGroup.writeEntry( conf_pollInterval, mDlg->comboBoxPoll->itemData( mDlg->comboBoxPoll->currentIndex() ).value<double>() );
     generalGroup.writeEntry( conf_saveInterval, mDlg->numInputSaveInterval->value() );
+    generalGroup.writeEntry( conf_useBitrate, mDlg->useBitrate->isChecked() );
     generalGroup.writeEntry( conf_statisticsDir,  mDlg->lineEditStatisticsDir->url().url() );
     generalGroup.writeEntry( conf_toolTipContent, mToolTipContent );
     generalGroup.writeEntry( conf_interfaces, list );
@@ -528,6 +575,7 @@ void ConfigDialog::defaults()
         KColorScheme scheme(QPalette::Active, KColorScheme::View);
         settings->colorDisabled = scheme.foreground( KColorScheme::InactiveText ).color();
         settings->colorUnavailable = scheme.foreground( KColorScheme::InactiveText ).color();
+        settings->iconFont = KGlobalSettings::generalFont();
         mSettingsMap.insert( interface, settings );
         mDlg->listBoxInterfaces->addItem( interface );
         mDlg->listBoxInterfaces->setCurrentRow( 0 );
@@ -538,14 +586,16 @@ void ConfigDialog::defaults()
     }
 
     // Default general settings
-    int index = mDlg->comboBoxPoll->findData( 1.0 );
+    GeneralSettings g;
+    int index = mDlg->comboBoxPoll->findData( g.pollInterval );
     if ( index >= 0 )
         mDlg->comboBoxPoll->setCurrentIndex( index );
-    mDlg->numInputSaveInterval->setValue( 60 );
-    mDlg->lineEditStatisticsDir->setUrl( KGlobal::dirs()->saveLocation( "data", "knemo/" ) );
+    mDlg->numInputSaveInterval->setValue( g.saveInterval );
+    mDlg->useBitrate->setChecked( g.useBitrate );
+    mDlg->lineEditStatisticsDir->setUrl( g.statisticsDir );
 
     // Default tool tips
-    mToolTipContent = defaultTip;
+    mToolTipContent = g.toolTipContent;
     setupToolTipTab();
 
     changed( true );
@@ -611,11 +661,12 @@ void ConfigDialog::updateControls( InterfaceSettings *settings )
     if ( index < 0 )
         index = findIndexFromName( TEXT_THEME );
     mDlg->comboBoxIconTheme->setCurrentIndex( index );
-    iconThemeChanged( index );
     mDlg->colorIncoming->setColor( settings->colorIncoming );
     mDlg->colorOutgoing->setColor( settings->colorOutgoing );
     mDlg->colorDisabled->setColor( settings->colorDisabled );
     mDlg->colorUnavailable->setColor( settings->colorUnavailable );
+    mDlg->iconFont->setCurrentFont( settings->iconFont );
+    iconThemeChanged( index );
     if ( settings->hideWhenDisconnected )
         index = 1;
     else if ( settings->hideWhenUnavailable )
@@ -626,6 +677,10 @@ void ConfigDialog::updateControls( InterfaceSettings *settings )
     comboHidingChanged( index );
     mDlg->checkBoxStatistics->setChecked( settings->activateStatistics );
     mDlg->warnThreshold->setValue( settings->warnThreshold );
+    index = mDlg->warnUnits->findData( settings->warnUnits );
+    mDlg->warnUnits->setCurrentIndex( index );
+    index = mDlg->warnType->findData( settings->warnType );
+    mDlg->warnType->setCurrentIndex( index );
     if ( settings->warnTotalTraffic )
         mDlg->warnRxTx->setChecked( true );
     else
@@ -711,6 +766,7 @@ void ConfigDialog::buttonNewSelected()
         KColorScheme scheme(QPalette::Active, KColorScheme::View);
         settings->colorDisabled = scheme.foreground( KColorScheme::InactiveText ).color();
         settings->colorUnavailable = scheme.foreground( KColorScheme::InactiveText ).color();
+        settings->iconFont = KGlobalSettings::generalFont();
         mSettingsMap.insert( ifname, settings );
         mDlg->listBoxInterfaces->setCurrentRow( mDlg->listBoxInterfaces->row( item ) );
         mDlg->pushButtonDelete->setEnabled( true );
@@ -768,6 +824,7 @@ void ConfigDialog::buttonAllSelected()
         KColorScheme scheme(QPalette::Active, KColorScheme::View);
         settings->colorDisabled = scheme.foreground( KColorScheme::InactiveText ).color();
         settings->colorUnavailable = scheme.foreground( KColorScheme::InactiveText ).color();
+        settings->iconFont = KGlobalSettings::generalFont();
         mSettingsMap.insert( ifname, settings );
         mDlg->listBoxInterfaces->addItem( ifname );
     }
@@ -841,8 +898,8 @@ QPixmap ConfigDialog::textIcon( QString incomingText, QString outgoingText, int
     QPainter p( &sampleIcon );
     p.setBrush( Qt::NoBrush );
     p.setOpacity( 1.0 );
-    QFont rxFont = setIconFont( incomingText, 22 );
-    QFont txFont = setIconFont( outgoingText, 22 );
+    QFont rxFont = setIconFont( incomingText, mDlg->iconFont->currentFont(), 22 );
+    QFont txFont = setIconFont( outgoingText, mDlg->iconFont->currentFont(), 22 );
     if ( rxFont.pointSizeF() > txFont.pointSizeF() )
         rxFont.setPointSizeF( txFont.pointSizeF() );
     p.setFont( rxFont );
@@ -964,6 +1021,13 @@ void ConfigDialog::iconThemeChanged( int set )
         return;
 
     KNemoTheme curTheme = mDlg->comboBoxIconTheme->itemData( mDlg->comboBoxIconTheme->currentIndex() ).value<KNemoTheme>();
+
+    if ( curTheme.internalName != TEXT_THEME )
+    {
+        mDlg->iconFontLabel->setEnabled( false );
+        mDlg->iconFont->setEnabled( false );
+    }
+
     if ( curTheme.internalName == TEXT_THEME ||
          curTheme.internalName == NETLOAD_THEME )
     {
@@ -976,6 +1040,8 @@ void ConfigDialog::iconThemeChanged( int set )
             mDlg->pixmapIncoming->setPixmap( textIcon( "123K", "0.0K", KNemoIface::Connected ) );
             mDlg->pixmapOutgoing->setPixmap( textIcon( "0.0K", "12K", KNemoIface::Connected ) );
             mDlg->pixmapTraffic->setPixmap( textIcon( "123K", "12K", KNemoIface::Connected ) );
+            mDlg->iconFontLabel->setEnabled( true );
+            mDlg->iconFont->setEnabled( true );
         }
         else
         {
@@ -1031,6 +1097,20 @@ void ConfigDialog::colorButtonChanged()
     if ( !mLock) changed( true );
 }
 
+void ConfigDialog::iconFontChanged( const QFont &font )
+{
+    InterfaceSettings* settings = getItemSettings();
+    if ( !settings )
+        return;
+
+    if ( font != settings->iconFont )
+    {
+        settings->iconFont = font;
+        iconThemeChanged( mDlg->comboBoxIconTheme->currentIndex() );
+    }
+    if ( !mLock ) changed( true );
+}
+
 void ConfigDialog::advancedButtonClicked()
 {
     InterfaceSettings* settings = getItemSettings();
@@ -1041,6 +1121,7 @@ void ConfigDialog::advancedButtonClicked()
     if ( t.exec() )
     {
         InterfaceSettings s = t.getSettings();
+        settings->trafficThreshold = s.trafficThreshold;
         settings->dynamicColor = s.dynamicColor;
         settings->colorIncomingMax = s.colorIncomingMax;
         settings->colorOutgoingMax = s.colorOutgoingMax;
@@ -1077,6 +1158,11 @@ void ConfigDialog::checkBoxCustomBillingToggled( bool on )
         return;
 
     settings->customBilling = on;
+    if ( on )
+        mDlg->warnType->setItemText( NotifyMonth, i18n( "Billing Period" ) );
+    else
+        mDlg->warnType->setItemText( NotifyMonth, i18n( "Month" ) );
+
     mDlg->billingStartInput->setDate( QDate::currentDate().addDays( 1 - mCalendar->day( QDate::currentDate() ) ) );
     mDlg->billingMonthsInput->setValue( 1 );
     if (!mLock) changed( true );
@@ -1127,6 +1213,29 @@ void ConfigDialog::warnThresholdChanged( double val )
     bool enable = settings->warnThreshold > 0.0;
     mDlg->warnRx->setEnabled( enable );
     mDlg->warnRxTx->setEnabled( enable );
+    mDlg->warnUnits->setEnabled( enable );
+    mDlg->warnPer->setEnabled( enable );
+    mDlg->warnType->setEnabled( enable );
+    if (!mLock) changed( true );
+}
+
+void ConfigDialog::warnUnitsChanged( int val )
+{
+    InterfaceSettings* settings = getItemSettings();
+    if ( !settings )
+        return;
+
+    settings->warnUnits = mDlg->warnUnits->itemData( val ).toInt();
+    if (!mLock) changed( true );
+}
+
+void ConfigDialog::warnTypeChanged( int val )
+{
+    InterfaceSettings* settings = getItemSettings();
+    if ( !settings )
+        return;
+
+    settings->warnType = mDlg->warnType->itemData( val ).toInt();
     if (!mLock) changed( true );
 }
 
@@ -1331,7 +1440,7 @@ void ConfigDialog::setupToolTipMap()
     // Cannot make this data static as the i18n macro doesn't seem
     // to work when called to early i.e. before setting the catalogue.
     mToolTips.insert( INTERFACE, i18n( "Interface" ) );
-#ifndef USE_KNOTIFICATIONITEM
+#ifndef HAVE_KSTATUSNOTIFIERITEM
     mToolTips.insert( ALIAS, i18n( "Alias" ) );
 #endif
     mToolTips.insert( STATUS, i18n( "Status" ) );
