@@ -21,8 +21,7 @@
 #ifndef GLOBAL_H
 #define GLOBAL_H
 
-#include <QDate>
-#include <KUrl>
+#include "data.h"
 
 /**
  * This file contains data structures and enums used in the knemo daemon.
@@ -31,26 +30,9 @@
  * @author Percy Leonhardt <percy@eris23.de>
  */
 
-struct GeneralData
-{
-    int toolTipContent;
-    double pollInterval;
-    int saveInterval;
-    KUrl statisticsDir;
-};
+// application wide settings are stored here
+extern GeneralSettings *generalSettings;
 
-struct StatisticEntry
-{
-    StatisticEntry()
-        : span( 0 ),
-          rxBytes( 0 ),
-          txBytes( 0 )
-    {}
-
-    QDate date;
-    int span;
-    quint64 rxBytes;
-    quint64 txBytes;
-};
+QString formattedRate( quint64 data, bool useBits );
 
 #endif // GLOBAL_H
