@@ -24,9 +24,11 @@
 #include <KColorScheme>
 #include <KNotification>
 #include <KWindowSystem>
+#include <kdeversion.h>
 #include <kio/global.h>
 
 #include "backends/backendbase.h"
+#include "global.h"
 #include "utils.h"
 #include "interface.h"
 #include "interfaceplotterdialog.h"
@@ -35,8 +37,7 @@
 #include "interfacestatisticsdialog.h"
 
 Interface::Interface( const QString &ifname,
-                      const BackendData* data,
-                      const GeneralData& generalData )
+                      const BackendData* data )
     : QObject(),
       mType( KNemoIface::UnknownType ),
       mState( KNemoIface::UnknownState ),
@@ -52,8 +53,7 @@ Interface::Interface( const QString &ifname,
       mStatusDialog( 0 ),
       mStatisticsDialog(  0 ),
       mPlotterDialog( 0 ),
-      mBackendData( data ),
-      mGeneralData( generalData )
+      mBackendData( data )
 {
     mPlotterDialog = new InterfacePlotterDialog( mName );
 
@@ -91,6 +91,7 @@ void Interface::configChanged()
     KColorScheme scheme(QPalette::Active, KColorScheme::View);
     mSettings.colorDisabled = interfaceGroup.readEntry( conf_colorDisabled, scheme.foreground( KColorScheme::InactiveText ).color() );
     mSettings.colorUnavailable = interfaceGroup.readEntry( conf_colorUnavailable, scheme.foreground( KColorScheme::InactiveText ).color() );
+    mSettings.iconFont = interfaceGroup.readEntry( conf_iconFont, s.iconFont );
     mSettings.dynamicColor = interfaceGroup.readEntry( conf_dynamicColor, s.dynamicColor );
     mSettings.colorIncomingMax = interfaceGroup.readEntry( conf_colorIncomingMax, s.colorIncomingMax );
     mSettings.colorOutgoingMax = interfaceGroup.readEntry( conf_colorOutgoingMax, s.colorOutgoingMax );
@@ -102,11 +103,16 @@ void Interface::configChanged()
     mSettings.activateStatistics = interfaceGroup.readEntry( conf_activateStatistics, s.activateStatistics );
     mSettings.trafficThreshold = clamp<unsigned int>(interfaceGroup.readEntry( conf_trafficThreshold, s.trafficThreshold ), 0, 1000 );
     mSettings.warnThreshold = clamp<double>(interfaceGroup.readEntry( conf_billingWarnThresh, s.warnThreshold ), 0.0, 9999.0 );
+    mSettings.warnUnits = clamp<int>(interfaceGroup.readEntry( conf_billingWarnUnits, s.warnUnits ), 0, 3 );
+    mSettings.warnType = clamp<int>(interfaceGroup.readEntry( conf_billingWarnType, s.warnType ), 0, 5 );
     mSettings.warnTotalTraffic = interfaceGroup.readEntry( conf_billingWarnRxTx, s.warnTotalTraffic );
 
-    // TODO: Some of the calendars are a bit buggy, so default to Gregorian for now
-    //mSettings.calendar = interfaceGroup.readEntry( conf_calendar, KGlobal::locale()->calendarType() );
-    mSettings.calendar = interfaceGroup.readEntry( conf_calendar, "gregorian" );
+    QString defaultCal;
+    if ( KDE::versionMajor() >= 4 && KDE::versionMinor() >= 4 )
+        defaultCal = KGlobal::locale()->calendarType();
+    else
+        defaultCal = "gregorian";
+    mSettings.calendar = interfaceGroup.readEntry( conf_calendar, defaultCal );
 
     mSettings.customBilling = interfaceGroup.readEntry( conf_customBilling, s.customBilling );
 
@@ -145,21 +151,21 @@ void Interface::configChanged()
     }
     mIcon.configChanged();
 
-    if ( mStatistics != 0 )
+    if ( mStatistics )
     {
         mStatistics->configChanged();
+        if ( !mSettings.activateStatistics )
+            stopStatistics();
     }
-
-    if ( mSettings.activateStatistics && mStatistics == 0 )
+    else if ( mSettings.activateStatistics )
     {
-        // user turned on statistics
         startStatistics();
     }
-    else if ( !mSettings.activateStatistics && mStatistics != 0 )
-    {
-        // user turned off statistics
-        stopStatistics();
-    }
+
+    if ( mStatisticsDialog != 0 )
+        mStatisticsDialog->configChanged();
+    if ( mPlotterDialog )
+        mPlotterDialog->useBitrate( generalSettings->useBitrate );
 }
 
 void Interface::processUpdate()
@@ -168,8 +174,13 @@ void Interface::processUpdate()
     unsigned int trafficThreshold = mSettings.trafficThreshold;
     mState = mBackendData->status;
 
-    mRxRate = mBackendData->incomingBytes / mGeneralData.pollInterval;
-    mTxRate = mBackendData->outgoingBytes / mGeneralData.pollInterval;
+    int units = 1;
+    if ( generalSettings->useBitrate )
+        units = 8;
+    mRxRate = mBackendData->incomingBytes * units / generalSettings->pollInterval;
+    mTxRate = mBackendData->outgoingBytes * units / generalSettings->pollInterval;
+    mRxRateStr = formattedRate( mRxRate, generalSettings->useBitrate );
+    mTxRateStr = formattedRate( mTxRate, generalSettings->useBitrate );
 
     QString title = mSettings.alias;
     if ( title.isEmpty() )
@@ -185,8 +196,8 @@ void Interface::processUpdate()
 
         if ( mStatistics )
         {
-            mStatistics->addIncomingData( mBackendData->incomingBytes );
-            mStatistics->addOutgoingData( mBackendData->outgoingBytes );
+            mStatistics->addRxBytes( mBackendData->incomingBytes );
+            mStatistics->addTxBytes( mBackendData->outgoingBytes );
         }
 
         updateTime();
@@ -230,7 +241,7 @@ void Interface::processUpdate()
         mIcon.updateTrayStatus();
 
     if ( mPlotterDialog )
-        mPlotterDialog->updatePlotter( mRxRate / 1024.0, mTxRate / 1024.0 );
+        mPlotterDialog->updatePlotter( mRxRate, mTxRate );
 
     mIcon.updateToolTip();
     if ( mStatusDialog )
@@ -244,6 +255,8 @@ void Interface::resetUptime()
     mUptimeString = "00:00:00";
     mRxRate = 0;
     mTxRate = 0;
+    mRxRateStr = formattedRate( mRxRate, generalSettings->useBitrate );
+    mTxRateStr = formattedRate( mTxRate, generalSettings->useBitrate );
 }
 
 void Interface::showStatusDialog( bool fromContextMenu )
@@ -280,36 +293,14 @@ void Interface::showStatisticsDialog()
             // should never happen but you never know...
             startStatistics();
         }
-        connect( mStatistics, SIGNAL( dayStatisticsChanged() ),
-                 mStatisticsDialog, SLOT( updateDays() ) );
-        connect( mStatistics, SIGNAL( weekStatisticsChanged() ),
-                 mStatisticsDialog, SLOT( updateWeeks() ) );
-        connect( mStatistics, SIGNAL( monthStatisticsChanged( bool ) ),
-                 mStatisticsDialog, SLOT( updateMonths( bool ) ) );
-        connect( mStatistics, SIGNAL( yearStatisticsChanged() ),
-                 mStatisticsDialog, SLOT( updateYears() ) );
-        connect( mStatistics, SIGNAL( currentEntryChanged() ),
-                 mStatisticsDialog, SLOT( updateCurrentEntry() ) );
-        connect( mStatisticsDialog, SIGNAL( clearStatistics() ),
-                 mStatistics, SLOT( clearStatistics() ) );
-
-        /* We need to show the dialog before we update the stats.  That way
-         * the viewport doesn't get messed up when we scroll to the most recent
-         * item. */
-        mStatisticsDialog->show();
-
-        mStatisticsDialog->updateDays();
-        mStatisticsDialog->updateWeeks();
-        mStatisticsDialog->updateMonths( false );
-        mStatisticsDialog->updateYears();
+        connect( mStatisticsDialog, SIGNAL( clearStatistics() ), mStatistics, SLOT( clearStatistics() ) );
     }
-    else
-        mStatisticsDialog->show();
+    mStatisticsDialog->show();
 }
 
 void Interface::updateTime()
 {
-    mRealSec += mGeneralData.pollInterval;
+    mRealSec += generalSettings->pollInterval;
     if ( mRealSec < 1.0 )
         return;
 
@@ -332,8 +323,8 @@ void Interface::updateTime()
 void Interface::startStatistics()
 {
     mStatistics = new InterfaceStatistics( this );
-    connect( mStatistics, SIGNAL( warnMonthlyTraffic( quint64 ) ),
-             this, SLOT( warnMonthlyTraffic( quint64 ) ) );
+    connect( mStatistics, SIGNAL( warnTraffic( quint64, quint64 ) ),
+             this, SLOT( warnTraffic( quint64, quint64 ) ) );
     if ( mStatusDialog != 0 )
     {
         connect( mStatistics, SIGNAL( currentEntryChanged() ),
@@ -352,14 +343,18 @@ void Interface::stopStatistics()
     mStatistics = 0;
 }
 
-void Interface::warnMonthlyTraffic( quint64 traffic )
+void Interface::warnTraffic( quint64 threshold, quint64 current )
 {
-    QString title = mSettings.alias;
-    if ( title.isEmpty() )
-        title = mName;
-
-    KNotification::event( "exceededMonthlyTraffic",
-                          i18n( "%1: Monthly traffic limit exceeded (currently %2)", title, KIO::convertSize( traffic ) )
+    // Don't use mSettings.alias since automatic text wrapping can
+    // cut off the bottom portion of the notification
+    KNotification::event( "exceededTraffic",
+                          i18n( "<table><tr><td style='padding-right:0.2em;'>%1:</td>"
+                                "<td>Exceeded traffic limit of %2\n"
+                                "(currently %3)</td></tr></table>",
+                                mName,
+                                KIO::convertSize( threshold ),
+                                KIO::convertSize( current )
+                              )
                         );
 }
 
