@@ -22,9 +22,8 @@
 #define INTERFACE_H
 
 #include <time.h>
-#include "data.h"
-#include "global.h"
 #include "interfaceicon.h"
+#include "data.h"
 
 class InterfacePlotterDialog;
 class InterfaceStatistics;
@@ -47,8 +46,7 @@ public:
      * Default Constructor
      */
     Interface(const QString& ifname,
-              const BackendData * const,
-              const GeneralData& generalData );
+              const BackendData * const );
 
     /**
      * Default Destructor
@@ -85,11 +83,6 @@ public:
         return mSettings;
     }
 
-    const GeneralData& getGeneralData() const
-    {
-        return mGeneralData;
-    }
-
     InterfaceStatistics* getStatistics()
     {
         return mStatistics;
@@ -105,6 +98,16 @@ public:
         return mTxRate;
     }
 
+    QString getRxRateStr()
+    {
+        return mRxRateStr;
+    }
+
+    QString getTxRateStr()
+    {
+        return mTxRateStr;
+    }
+
     /**
      * Called from reparseConfiguration() when the user changed
      * the settings.
@@ -139,9 +142,9 @@ public slots:
 
 private slots:
     /**
-     * Emit a notification when monthly traffic exceeds a threshold
+     * Emit a notification when traffic exceeds a threshold
      */
-    void warnMonthlyTraffic( quint64 );
+    void warnTraffic( quint64 threshold, quint64 current );
 
 private:
     /**
@@ -175,6 +178,8 @@ private:
     QString mUptimeString;
     unsigned long mRxRate;
     unsigned long mTxRate;
+    QString mRxRateStr;
+    QString mTxRateStr;
     InterfaceIcon mIcon;
     InterfaceSettings mSettings;
     InterfaceStatistics* mStatistics;
@@ -182,7 +187,6 @@ private:
     InterfaceStatisticsDialog* mStatisticsDialog;
     InterfacePlotterDialog* mPlotterDialog;
     const BackendData* mBackendData;
-    const GeneralData& mGeneralData;
 };
 
 #endif // INTERFACE_H
