@@ -18,6 +18,7 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include <math.h>
 #include <unistd.h>
 
 #include <QPainter>
@@ -33,14 +34,13 @@
 #include <KProcess>
 #include <KStandardDirs>
 
-#include "data.h"
+#include "global.h"
 #include "utils.h"
 #include "interface.h"
 #include "knemodaemon.h"
 #include "interfaceicon.h"
 #include "interfacetray.h"
 
-#define MINIMAL_MAX 1024
 #define SHRINK_MAX 0.75
 #define HISTSIZE_STORE 0.5
 
@@ -94,7 +94,7 @@ void InterfaceIcon::configChanged()
     int rightMargin = (margins - midMargin)/2;
     leftMargin = margins-midMargin - rightMargin;
     midMargin = leftMargin + barWidth+ midMargin;
-    histSize = HISTSIZE_STORE/mInterface->getGeneralData().pollInterval;
+    histSize = HISTSIZE_STORE/generalSettings->pollInterval;
     if ( histSize < 2 )
         histSize = 2;
 
@@ -156,8 +156,8 @@ void InterfaceIcon::updateIconImage( int status )
     {
         iconName += ICON_ERROR;
     }
-#ifdef USE_KNOTIFICATIONITEM
-    mTray->setIconByPixmap( KIcon( iconName ) );
+#ifdef HAVE_KSTATUSNOTIFIERITEM
+    mTray->setIconByName( iconName );
 #else
     mTray->setIcon( KIcon( iconName ) );
 #endif
@@ -180,12 +180,15 @@ int InterfaceIcon::calcHeight( QList<unsigned long>& hist, unsigned int& net_max
         QList<unsigned long>sortedMax( hist );
         qSort( sortedMax );
         unsigned long max = sortedMax.last();
+        int multiplier = 1024;
+        if ( generalSettings->useBitrate )
+            multiplier = 1000;
         if( rate > net_max )
         {
             net_max = rate;
         }
         else if( max < net_max * SHRINK_MAX
-                && net_max * SHRINK_MAX >= MINIMAL_MAX )
+                && net_max * SHRINK_MAX >= multiplier )
         {
             net_max *= SHRINK_MAX;
         }
@@ -317,37 +320,53 @@ void InterfaceIcon::updateBars( bool doUpdate )
     p.fillRect( leftRect, outGrad );
     brush = QBrush( topOutGrad );
     p.fillRect( topLeftRect, topOutGrad );
-#ifdef USE_KNOTIFICATIONITEM
-    mTray->setIconByPixmap( textIcon );
+#ifdef HAVE_KSTATUSNOTIFIERITEM
+    mTray->setIconByPixmap( barIcon );
 #else
     mTray->setIcon( barIcon );
 #endif
 }
 
-QString InterfaceIcon::compactTrayText(unsigned long bytes )
+QString InterfaceIcon::compactTrayText(unsigned long data )
 {
-    QString byteString;
+    QString dataString;
     // Space is tight, so no space between number and units, and the complete
     // string should be no more than 4 chars.
     /* Visually confusing to display bytes
     if ( bytes < 922 ) // 922B = 0.9K
         byteString = i18n( "%1B", bytes );
     */
-    if ( bytes < 10189 ) // < 9.95K
-        byteString = i18n( "%1K", QString::number( bytes/1024.0, 'f', 1 ) );
-    else if ( bytes < 1023488 ) // < 999.5
-        byteString = i18n( "%1K", QString::number( bytes/1024.0, 'f', 0 ) );
-    else if ( bytes < 10433331 ) // < 9.95M
-        byteString = i18n( "%1M", QString::number( bytes/1048576.0, 'f', 1 ) );
-    else if ( bytes < 1048051712 ) // < 999.5G
-        byteString = i18n( "%1M", QString::number( bytes/1048576.0, 'f', 0 ) );
-    else if ( bytes < 10683731148.0 ) // < 9.95G
-        // xgettext: no-c-format
-        byteString = i18n( "%1G", QString::number( bytes/1073741824.0, 'f', 1 ) );
-    else
-        // xgettext: no-c-format
-        byteString = i18n( "%1G", QString::number( bytes/1073741824.0, 'f', 0) );
-    return byteString;
+    double multiplier = 1024;
+    if ( generalSettings->useBitrate )
+        multiplier = 1000;
+
+    int precision = 0;
+    if ( data < multiplier*9.95 ) // < 9.95K
+    {
+        precision = 1;
+    }
+    if ( data < multiplier*999.5 ) // < 999.5K
+    {
+        if ( generalSettings->useBitrate )
+            dataString = i18n( "%1k", QString::number( data/multiplier, 'f', precision ) );
+        else
+            dataString = i18n( "%1K", QString::number( data/multiplier, 'f', precision ) );
+        return dataString;
+    }
+
+    if ( data < pow(multiplier, 2)*9.95 ) // < 9.95M
+        precision = 1;
+    if ( data < pow(multiplier, 2)*999.5 ) // < 999.5M
+    {
+        dataString = i18n( "%1M", QString::number( data/pow(multiplier, 2), 'f', precision ) );
+        return dataString;
+    }
+
+    if ( data < pow(multiplier, 3)*9.95 ) // < 9.95G
+        precision = 1;
+    // xgettext: no-c-format
+    dataString = i18n( "%1G", QString::number( data/pow(multiplier, 3), 'f', precision) );
+    return dataString;
 }
 
 void InterfaceIcon::updateIconText( bool doUpdate )
@@ -394,8 +413,8 @@ void InterfaceIcon::updateIconText( bool doUpdate )
     KColorScheme scheme(QPalette::Active, KColorScheme::View);
 
     // rxFont and txFont should be the same size per poll period
-    QFont rxFont = setIconFont( textIncoming, iconWidth );
-    QFont txFont = setIconFont( textOutgoing, iconWidth );
+    QFont rxFont = setIconFont( textIncoming, mInterface->getSettings().iconFont, iconWidth );
+    QFont txFont = setIconFont( textOutgoing, mInterface->getSettings().iconFont, iconWidth );
     if ( rxFont.pointSizeF() > txFont.pointSizeF() )
         rxFont.setPointSizeF( txFont.pointSizeF() );
 
@@ -406,7 +425,7 @@ void InterfaceIcon::updateIconText( bool doUpdate )
     p.setFont( rxFont );
     p.setPen( txColor );
     p.drawText( bottomRect, Qt::AlignCenter | Qt::AlignRight, textOutgoing );
-#ifdef USE_KNOTIFICATIONITEM
+#ifdef HAVE_KSTATUSNOTIFIERITEM
     mTray->setIconByPixmap( textIcon );
 #else
     mTray->setIcon( textIcon );
@@ -523,7 +542,7 @@ void InterfaceIcon::updateTrayStatus()
         else
             updateIconImage( mInterface->getState() );
         updateMenu();
-#ifndef USE_KNOTIFICATIONITEM
+#ifndef HAVE_KSTATUSNOTIFIERITEM
         mTray->show();
 #endif
     }
