@@ -21,13 +21,11 @@
 #ifndef INTERFACEICON_H
 #define INTERFACEICON_H
 
-#include <QMap>
-#include <QSystemTrayIcon>
-
 class Interface;
 class InterfaceTray;
 class KAction;
 class KActionCollection;
+class KProcess;
 class QAction;
 
 /**
@@ -53,30 +51,27 @@ public:
      */
     virtual ~InterfaceIcon();
 
+signals:
+    void statisticsSelected();
+
+public slots:
+    /*
+     * Creates or deletes the tray icon
+     */
+    void updateTrayStatus();
+
+    /*
+     * Change the tooltip according to the alias of the interface
+     */
+    void updateToolTip();
+
     /*
      * Fill the context menu with entries if the user configured
      * start and stop command
      */
     void updateMenu();
 
-signals:
-    void statisticsSelected();
-
-public slots:
-    /*
-     * Changes the icon image displayed in the tray
-     */
-    void updateStatus( int status );
-
-    /*
-     * Creates or deletes the tray icon
-     */
-    void updateTrayStatus( int previousState );
-
-    /*
-     * Change the tooltip according to the alias of the interface
-     */
-    void updateToolTip();
+    void configChanged();
 
 private slots:
     /*
@@ -90,26 +85,56 @@ private slots:
      */
     void menuTriggered( QAction * );
 
-    void iconActivated( QSystemTrayIcon::ActivationReason reason );
+    /*
+     * Called when a custom command finishes
+     */
+    void processFinished();
 
+    /*
+     * Returns a string with a compact transfer rate
+     * This should not be more than 4 chars, including the units
+     */
+    QString compactTrayText( unsigned long );
+
+    void showStatus();
     void showGraph();
     void showStatistics();
 
 private:
+    /*
+     * Changes the icon displayed in the tray
+     */
+    void updateIconImage( int status );
+
+    QColor calcColor( QList<unsigned long>& hist, const QColor& low, const QColor& high, int hival );
+    int calcHeight( QList<unsigned long>& hist, unsigned int& net_max );
+    void updateBars( bool doUpdate = false );
+    void updateIconText( bool doUpdate = false );
     // the interface this icon belongs to
     Interface* mInterface;
     // the real tray icon
     InterfaceTray* mTray;
+    QList<KProcess*> processList;
     KActionCollection* commandActions;
+    KAction* statusAction;
     KAction* plotterAction;
     KAction* statisticsAction;
     KAction* configAction;
-
-    static const QString ICON_DISCONNECTED;
-    static const QString ICON_CONNECTED;
-    static const QString ICON_INCOMING;
-    static const QString ICON_OUTGOING;
-    static const QString ICON_TRAFFIC;
+    QString textIncoming;
+    QString textOutgoing;
+    QColor colorIncoming;
+    QColor colorOutgoing;
+    int iconWidth;
+    int histSize;
+    int barIncoming;
+    int barOutgoing;
+    int barWidth;
+    int leftMargin;
+    int midMargin;
+    QList<unsigned long>inHist;
+    QList<unsigned long>outHist;
+    unsigned int inMaxRate;
+    unsigned int outMaxRate;
 };
 
 #endif // INTERFACEICON_H
