@@ -28,7 +28,7 @@
   #include <netlink/netlink.h>
 #endif
 
-#include "data.h"
+#include "global.h"
 #include "interface.h"
 #include "interfacestatistics.h"
 #include "interfacestatusdialog.h"
@@ -190,10 +190,8 @@ void InterfaceStatusDialog::doAvailable( const BackendData* data )
     ui.textLabelPacketsReceived->setText( QString::number( data->rxPackets ) );
     ui.textLabelBytesSend->setText( data->txString );
     ui.textLabelBytesReceived->setText( data->rxString );
-    unsigned long bytesPerSecond = data->outgoingBytes / mInterface->getGeneralData().pollInterval;
-    ui.textLabelSpeedSend->setText( KIO::convertSize( bytesPerSecond  ) + i18n( "/s" ) );
-    bytesPerSecond = data->incomingBytes / mInterface->getGeneralData().pollInterval;
-    ui.textLabelSpeedReceived->setText( KIO::convertSize( bytesPerSecond ) + i18n( "/s" ) );
+    ui.textLabelSpeedSend->setText( mInterface->getTxRateStr() );
+    ui.textLabelSpeedReceived->setText( mInterface->getRxRateStr() );
 }
 
 void InterfaceStatusDialog::doConnected( const BackendData *data )
@@ -364,27 +362,24 @@ void InterfaceStatusDialog::doUnavailable()
 
 void InterfaceStatusDialog::statisticsChanged()
 {
-    InterfaceStatistics* statistics = mInterface->getStatistics();
-
-    if ( statistics == 0 )
-    {
+    InterfaceStatistics *stat = mInterface->getStatistics();
+    if ( stat == 0 )
         return;
-    }
 
-    const StatisticEntry* entry = statistics->getCurrentDay();
-    ui.textLabelTodaySent->setText( KIO::convertSize( entry->txBytes ) );
-    ui.textLabelTodayReceived->setText( KIO::convertSize( entry->rxBytes ) );
-    ui.textLabelTodayTotal->setText( KIO::convertSize( entry->txBytes + entry->rxBytes ) );
+    StatisticsModel * statistics = stat->getStatistics( StatisticsModel::Day );
+    ui.textLabelTodaySent->setText( statistics->txText() );
+    ui.textLabelTodayReceived->setText( statistics->rxText() );
+    ui.textLabelTodayTotal->setText( statistics->totalText() );
 
-    entry = statistics->getCurrentMonth();
-    ui.textLabelMonthSent->setText( KIO::convertSize( entry->txBytes ) );
-    ui.textLabelMonthReceived->setText( KIO::convertSize( entry->rxBytes ) );
-    ui.textLabelMonthTotal->setText( KIO::convertSize( entry->txBytes + entry->rxBytes ) );
+    statistics = stat->getStatistics( StatisticsModel::Month );
+    ui.textLabelMonthSent->setText( statistics->txText() );
+    ui.textLabelMonthReceived->setText( statistics->rxText() );
+    ui.textLabelMonthTotal->setText( statistics->totalText() );
 
-    entry = statistics->getCurrentYear();
-    ui.textLabelYearSent->setText( KIO::convertSize( entry->txBytes ) );
-    ui.textLabelYearReceived->setText( KIO::convertSize( entry->rxBytes ) );
-    ui.textLabelYearTotal->setText( KIO::convertSize( entry->txBytes + entry->rxBytes ) );
+    statistics = stat->getStatistics( StatisticsModel::Year );
+    ui.textLabelYearSent->setText( statistics->txText() );
+    ui.textLabelYearReceived->setText( statistics->rxText() );
+    ui.textLabelYearTotal->setText( statistics->totalText() );
 }
 
 #include "interfacestatusdialog.moc"
