@@ -27,6 +27,7 @@
 #include <KStandardDirs>
 
 #include "config-knemo.h"
+#include "global.h"
 #include "knemodaemon.h"
 #include "interface.h"
 #include "backends/backendfactory.h"
@@ -35,6 +36,7 @@
 QString KNemoDaemon::sSelectedInterface = QString::null;
 
 BackendBase *backend = NULL;
+GeneralSettings *generalSettings = NULL;
 
 KNemoDaemon::KNemoDaemon()
     : QObject(),
@@ -46,6 +48,7 @@ KNemoDaemon::KNemoDaemon()
       mColorOutgoing( 0xFF7F08 ),
       mColorBackground( 0x313031 )
 {
+    generalSettings = new GeneralSettings();
     backend = BackendFactory::backend();
     QDBusConnection::sessionBus().registerObject("/knemo", this, QDBusConnection::ExportScriptableSlots);
     mPollTimer = new QTimer();
@@ -63,6 +66,7 @@ KNemoDaemon::~KNemoDaemon()
         Interface *interface = mInterfaceHash.take( key );
         delete interface;
     }
+    delete generalSettings;
 }
 
 void KNemoDaemon::readConfig()
@@ -74,12 +78,14 @@ void KNemoDaemon::readConfig()
     config->reparseConfiguration();
 
     // General
+    GeneralSettings g;
     KConfigGroup generalGroup( config, confg_general );
-    mGeneralData.pollInterval = clamp<double>(generalGroup.readEntry( conf_pollInterval, 1.0 ), 0.1, 2.0 );
-    mGeneralData.pollInterval = validatePoll( mGeneralData.pollInterval );
-    mGeneralData.saveInterval = clamp<int>(generalGroup.readEntry( conf_saveInterval, 60 ), 0, 300 );
-    mGeneralData.statisticsDir = generalGroup.readEntry( conf_statisticsDir, KGlobal::dirs()->saveLocation( "data", "knemo/" ) );
-    mGeneralData.toolTipContent = generalGroup.readEntry( conf_toolTipContent, defaultTip );
+    generalSettings->pollInterval = clamp<double>(generalGroup.readEntry( conf_pollInterval, g.pollInterval ), 0.1, 2.0 );
+    generalSettings->pollInterval = validatePoll( generalSettings->pollInterval );
+    generalSettings->useBitrate = generalGroup.readEntry( conf_useBitrate, g.useBitrate );
+    generalSettings->saveInterval = clamp<int>(generalGroup.readEntry( conf_saveInterval, g.saveInterval ), 0, 300 );
+    generalSettings->statisticsDir = generalGroup.readEntry( conf_statisticsDir, g.statisticsDir );
+    generalSettings->toolTipContent = generalGroup.readEntry( conf_toolTipContent, g.toolTipContent );
     // If we already have an Interfaces key--even if its empty--then we
     // shouldn't try to set up a default interface
     if ( generalGroup.hasKey( conf_interfaces ) )
@@ -124,7 +130,7 @@ void KNemoDaemon::readConfig()
         if ( !mInterfaceHash.contains( key ) )
         {
             const BackendData * data = backend->add( key );
-            Interface *iface = new Interface( key, data, mGeneralData );
+            Interface *iface = new Interface( key, data );
             mInterfaceHash.insert( key, iface );
             newIfaces << key;
         }
@@ -145,7 +151,7 @@ void KNemoDaemon::readConfig()
             connect( backend, SIGNAL( updateComplete() ), iface, SLOT( processUpdate() ) );
         }
     }
-    mPollTimer->start( mGeneralData.pollInterval * 1000 );
+    mPollTimer->start( generalSettings->pollInterval * 1000 );
 }
 
 void KNemoDaemon::reparseConfiguration()
@@ -178,7 +184,7 @@ void KNemoDaemon::createAboutData()
                       ki18n( description ),
                       KAboutData::License_GPL_V2,
                       KLocalizedString(),
-                      ki18n( "Copyright (C) 2004, 2005, 2006 Percy Leonhardt\nCopyright (C) 2009 John Stamp\n\nSignal plotter taken from KSysGuard\nCopyright (C) 1999 - 2002, Chris Schlaeger\nCopyright (C) 2006 John Tapsell" ),
+                      ki18n( "Copyright (C) 2004, 2005, 2006 Percy Leonhardt\nCopyright (C) 2009 John Stamp\n\nSignal plotter taken from KSysGuard\nCopyright (C) 2006 - 2009 John Tapsell" ),
                       "http://extragear.kde.org/apps/knemo/",
                       "jstamp@users.sourceforge.net");
 
